# Generated by roxygen2: do not edit by hand

export("%>%")
export(Boxplot_data)
export(Corrplot_data)
export(Densityplot_data)
export(MAplot_DE_fn)
export(MDSplot_data)
export(QQplot_data)
export(best_combination)
export(top_table_fn)
export(volcanoplot_DE_fn)
importFrom(magrittr,"%>%")
