#' Top table for Yeast Lysate - UPS1 dataset
#'
#' @description Top table can be used for identifying the differential abundance analysis of proteins in the dataset.
#'
#' @format A data frame with 835 rows and 6 variables along with 'Fasta headers':
#' \describe{
#'   \item{logFC}{Log fold change values}
#'   \item{AveExpr}{Average intensity values}
#'   \item{t}{t-statistic values}
#'   \item{P.Value}{P-values}
#'   \item{adj.P.Val}{Adjusted P-values}
#'   \item{B}{B-statistic values}
#'}
"yeast_top_table"

